@@ -168,6 +168,14 @@ class Twilio2FAMixin(object):
 
             del self.request.session[key_]
 
+    def get_phone_number(self):
+        return get_setting(
+            "PHONE_NUMBER_CB",
+            callback_kwargs={
+                "user": self.request.user
+            }
+        )
+
 
 class Twilio2FAVerificationMixin(Twilio2FAMixin):
     """
@@ -177,12 +185,7 @@ class Twilio2FAVerificationMixin(Twilio2FAMixin):
     def setup(self, request, *args, **kwargs):
         super().setup(request, *args, **kwargs)
 
-        self.phone_number = get_setting(
-            "PHONE_NUMBER_CB",
-            callback_kwargs={
-                "user": self.request.user
-            }
-        )
+        self.phone_number = self.get_phone_number()
 
         try:
             self.phone_number = parse_phone_number(self.phone_number)
@@ -353,6 +356,14 @@ class Twilio2FARegistrationFormView(Twilio2FAMixin, FormView):
 class Twilio2FARegisterView(Twilio2FARegistrationFormView):
     template_name = "twilio_2fa/register.html"
 
+    def get(self, request, *args, **kwargs):
+        phone_number = self.get_phone_number()
+
+        if phone_number:
+            return self.get_redirect("start")
+
+        return super().get(request, *args, **kwargs)
+
     def get_context_data(self, **kwargs):
         ctx = super().get_context_data(**kwargs)
 
@@ -371,16 +382,28 @@ class Twilio2FARegisterView(Twilio2FARegistrationFormView):
 class Twilio2FAChangeView(Twilio2FARegistrationFormView):
     template_name = "twilio_2fa/change.html"
 
+    def setup(self, request, *args, **kwargs):
+        super().setup(request, *args, **kwargs)
+
+        self.allow_change = get_setting(
+            "ALLOW_CHANGE",
+            default=False
+        )
+
+        self.allow_user_change = get_setting(
+            "ALLOW_USER_CHANGE_CB",
+            default=False,
+            callback_kwargs={
+                "user": request.user
+            }
+        )
+
     def get_context_data(self, **kwargs):
         ctx = super().get_context_data(**kwargs)
 
         ctx["is_optional"] = False
         ctx["skip_href"] = None
-
-        ctx["can_change"] = get_setting(
-            "ALLOW_CHANGE",
-            default=True
-        )
+        ctx["can_change"] = self.allow_change and self.allow_user_change
 
         if not ctx["can_change"]:
             messages.error(
